@@ -1,4 +1,5 @@
 import copy
+from numpy import unique
 from inspect import isfunction
 import itertools
 from math import inf, pi, e
@@ -1090,3 +1091,14 @@ def index_by(f, list):
         {},
         list
     )
+
+
+def one_unique_or_raise(values):
+    """
+        Returns the single unique value in values or raise if there isn't one
+    :param values: List of values that can be compared with unique
+    :return:
+    """
+    if compose(equals(1), length, lambda v: unique(v).tolist(), length)(values):
+        return head(values)
+    raise Exception(f'Expected one unique value in values, found {values}')
